OC.L10N.register(
    "core",
    {
    "Please select a file." : "Palun vali fail.",
    "File is too big" : "Fail on liiga suur",
    "The selected file is not an image." : "Valitud fail ei ole pilt.",
    "The selected file cannot be read." : "Valitud faili ei ole võimalik lugeda.",
    "The file was uploaded" : "Fail laaditi üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaaditud fail on suurem kui php.ini failis määratud upload_max_filesize direktiiv",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaaditud fail on suurem kui HTML vormil määratud MAX_FILE_SIZE direktiiv",
    "The file was only partially uploaded" : "Fail laaditi üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei laaditud üles",
    "Missing a temporary folder" : "Ajutine kaust on puudu",
    "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
    "A PHP extension stopped the file upload" : "PHP laiendus peatas faili üleslaadimise",
    "Invalid file provided" : "Vigane fail",
    "No image or file provided" : "Ühtegi pilti või faili pole pakutud",
    "Unknown filetype" : "Tundmatu failitüüp",
    "An error occurred. Please contact your admin." : "Tekkis tõrge. Palun võta ühendust administraatoriga.",
    "Invalid image" : "Vigane pilt",
    "No temporary profile picture available, try again" : "Ühtegi ajutist profiilipilti pole saadaval, proovi uuesti",
    "No crop data provided" : "Lõikeandmeid ei leitud",
    "No valid crop data provided" : "Kehtivaid lõikeandmeid ei leitud",
    "Crop is not square" : "Lõikamine pole ruudukujuline",
    "State token does not match" : "Oleku tunnusluba ei klapi",
    "Invalid app password" : "Rakenduse vale salasõna",
    "Could not complete login" : "Sisselogimine ebaõnnestus",
    "State token missing" : "Oleku tunnusluba on puudu",
    "Your login token is invalid or has expired" : "Sinu sisselogimise tunnusluba on kas vigane või aegunud",
    "Please use original client" : "Palun kasuta algupärast klienti",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "See Nextcloudi kogukonnaversioon pole toetatud ja tõuketeenuste kasutatavus on piiratud.",
    "Login" : "Logi sisse",
    "Unsupported email length (>255)" : "E-kirja pikkus pole toetatud (>255)",
    "Password reset is disabled" : "Salasõna lähtestamine on välja lülitatud",
    "Could not reset password because the token is expired" : "Kuna tunnusluba on aegunud, siis salasõna lähtestamine pole võimalik",
    "Could not reset password because the token is invalid" : "Kuna tunnusluba on vigane, siis salasõna lähtestamine pole võimalik",
    "Password is too long. Maximum allowed length is 469 characters." : "Salasõna on liiga pikk. Suurim lubatud pikkus on 469 sümbolit.",
    "%s password reset" : "Salasõna lähtestamine: %s",
    "Password reset" : "Salasõna lähtestamine ",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Oma salasõna lähtestamiseks klõpsi järgnevat nuppu. Kui sa ei ole salasõna lähtestamist soovinud, siis palun eira seda e-kirja.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Oma salasõna lähtestamiseks klõpsi järgnevat linki. Kui sa ei ole salasõna lähtestamist soovinud, siis palun eira seda e-kirja.",
    "Reset your password" : "Lähtesta oma salasõna",
    "The given provider is not available" : "Antud teenusepakkuja pole saadaval",
    "Task not found" : "Ülesannet ei leidu",
    "Internal error" : "Sisemine viga",
    "Not found" : "Ei leidu",
    "Node is locked" : "Sõlm on lukus",
    "Bad request" : "Vigane päring",
    "Requested task type does not exist" : "Küsitud ülesannete tüüpi ei leidu",
    "Necessary language model provider is not available" : "Vajaliku keelemudeli teenusepakkuja pole saadaval",
    "No text to image provider is available" : "Ühtegi optilise tekstituvastuse teenusepakkujat pole saadaval",
    "Image not found" : "Pilti ei leidu",
    "No translation provider available" : "Ühtegi tõlketeenuse pakkujat pole saadaval",
    "Could not detect language" : "Ei suutnud keelt tuvastada",
    "Unable to translate" : "Viga tõlkimisel",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Paranduse samm:",
    "Repair info:" : "Paranduse teave:",
    "Repair warning:" : "Paranduse hoiatus:",
    "Repair error:" : "Paranduse viga:",
    "Nextcloud Server" : "Nextcloudi server",
    "Some of your link shares have been removed" : "Mõned sinu linkide jagamised on eemaldatud",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Turvavea tõttu pidime mõned sinu linkide jagamised eemaldama. Lisateabe lugemiseks palun klõpsi järgnevat linki.",
    "The account limit of this instance is reached." : "Selle serveri kasutajakontode arvu ülempiir on käes.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Kasutajakontode arvu ülepiiri suurendamiseks sisesta oma tellimuse võti tugiteenuste rakenduses. Samaga saad kasutusele võtta ka kõik Nextcloud Enterprise'i lisavõimalused, mille kasutamine suurtes organisatsioonides on soovitatav.",
    "Learn more ↗" : "Lisateave ↗",
    "Preparing update" : "Valmistan ette uuendamist",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Palun kasuta uuendamiseks käsurida, kuna uuendamine veebibrauserist on config.php failis välja lülitatud.",
    "Turned on maintenance mode" : "Hooldusrežiim sisse lülitatud",
    "Turned off maintenance mode" : "Hooldusrežiim välja lülitatud",
    "Maintenance mode is kept active" : "Hooldusrežiim on aktiivne",
    "Updating database schema" : "Andmebaasi skeemi uuendamine",
    "Updated database" : "Andmebaas uuendatud",
    "Update app \"%s\" from App Store" : "Uuenda „%s“ rakendust rakenduste poest",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontrollitakse, kas %s andmebaasi skeemi saab uuendada (see võib võtta kaua aega, sõltuvalt andmebaasi suurusest)",
    "Updated \"%1$s\" to %2$s" : "„%1$s“ on uuendatud versioonini %2$s",
    "Set log level to debug" : "Seadista veaotsinguks vajalik logimise tase",
    "Reset log level" : "Lähtesta logimise tase",
    "Starting code integrity check" : "Koodi terviklikkuse kontrolli alustamine",
    "Finished code integrity check" : "Koodi terviklikkuse kontrolli lõpp",
    "%s (incompatible)" : "%s (pole ühilduv)",
    "The following apps have been disabled: %s" : "Järgmised rakendused lülitati välja: %s",
    "Already up to date" : "On juba ajakohane",
    "Windows Command Script" : "Windows Commandi skript",
    "Electronic book document" : "E-raamatu dokument",
    "TrueType Font Collection" : "TrueType'i kirjatüüpide kogumik",
    "Web Open Font Format" : "Web Open Font vorming",
    "GPX geographic data" : "GPX-i geoandmed",
    "Gzip archive" : "Gzipi arhiivifail",
    "Adobe Illustrator document" : "Adobe Illustratori dokument",
    "Java source code" : "Java lähtekood",
    "JavaScript source code" : "JavaScripti lähtekood",
    "JSON document" : "JSON-dokument",
    "Microsoft Access database" : "Microsoft Accessi andmebaas",
    "Microsoft OneNote document" : "Microsoft OneNote'i dokument",
    "Microsoft Word document" : "Microsoft Wordi dokument",
    "Unknown" : "Teadmata",
    "PDF document" : "PDF-dokument",
    "PostScript document" : "PostScripti dokument",
    "RSS summary" : "RSS-i kokkuvõte",
    "Android package" : "Androidi pakett",
    "KML geographic data" : "KML-i geoandmed",
    "KML geographic compressed data" : "KML-i pakitud geoandmed",
    "Lotus Word Pro document" : "Lotus Word Pro dokument",
    "Excel spreadsheet" : "Exceli arvutustabel",
    "Excel add-in" : "Exceli lisamoodul",
    "Excel 2007 binary spreadsheet" : "Excel 2007 kompileeritud arvutustabel",
    "Excel spreadsheet template" : "Exceli arvutustabeli mall",
    "Outlook Message" : "Outlooki e-kiri",
    "PowerPoint presentation" : "PowerPointi esitlus",
    "PowerPoint add-in" : "PowerPointi lisamoodul",
    "PowerPoint presentation template" : "PowerPointi esitluse mall",
    "Word document" : "Wordi dokument",
    "ODF formula" : "ODF-i valem",
    "ODG drawing" : "ODG joonistus",
    "ODG drawing (Flat XML)" : "ODG joonistus (Flat XML)",
    "ODG template" : "ODG joonistuse mall",
    "ODP presentation" : "ODP esitlus",
    "ODP presentation (Flat XML)" : "ODP esitlus (Flat XML)",
    "ODP template" : "ODP esitluse mall",
    "ODS spreadsheet" : "ODS-i arvutustabel",
    "ODS spreadsheet (Flat XML)" : "ODS-i arvutustabel (Flat XML)",
    "ODS template" : "ODS-i arvutustabeli mall",
    "ODT document" : "ODT dokument",
    "ODT document (Flat XML)" : "ODT dokument (Flat XML)",
    "ODT template" : "ODT dokumendi mall",
    "PowerPoint 2007 presentation" : "PowerPoint 2007 esitlus",
    "PowerPoint 2007 show" : "PowerPoint 2007 slaidiesitlus",
    "PowerPoint 2007 presentation template" : "PowerPoint 2007 esitluse mall",
    "Excel 2007 spreadsheet" : "Excel 2007 arvutustabel",
    "Excel 2007 spreadsheet template" : "Excel 2007 arvutustabeli mall",
    "Word 2007 document" : "Word 2007 dokument",
    "Word 2007 document template" : "Word 2007 dokumendimall",
    "Microsoft Visio document" : "Microsoft Visio dokument",
    "WordPerfect document" : "WordPerfecti dokument",
    "7-zip archive" : "7-zip arhiivifail",
    "Blender scene" : "Blenderi stseen",
    "Bzip2 archive" : "Bzip2 arhiivifail",
    "Debian package" : "Debian pakett",
    "FictionBook document" : "FictionBooki dokument",
    "Unknown font" : "Tundmatu kirjatüüp",
    "Krita document" : "Krita dokument",
    "Mobipocket e-book" : "Mobipocketi e-raamat",
    "Windows Installer package" : "Windows Installeri pakett",
    "Perl script" : "Perli skript",
    "PHP script" : "PHP skript",
    "Tar archive" : "Tari arhiivifail",
    "XML document" : "XML-dokument",
    "YAML document" : "YAML-dokument",
    "Zip archive" : "Zipi arhiivifail",
    "Zstandard archive" : "Zstandardi arhiivifail",
    "AAC audio" : "AAC helifail",
    "FLAC audio" : "FLAC helifail",
    "MPEG-4 audio" : "MPEG-4 helifail",
    "MP3 audio" : "MP3 helifail",
    "Ogg audio" : "Ogg helifail",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe standardne helifail",
    "WebM audio" : "WebM helifail",
    "MP3 ShoutCast playlist" : "MP3 ShoutCasti esitusloend",
    "Windows BMP image" : "Windows BMP pilt",
    "Better Portable Graphics image" : "Better Portable Graphicsi pilt",
    "EMF image" : "EMF pilt",
    "GIF image" : "GIF pilt",
    "HEIC image" : "HEIC pilt",
    "HEIF image" : "HEIF pilt",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 pilt",
    "JPEG image" : "JPEG pilt",
    "PNG image" : "PNG pilt",
    "SVG image" : "SVG pilt",
    "Truevision Targa image" : "Truevision Targa pilt",
    "TIFF image" : "TIFF pilt",
    "WebP image" : "WebP pilt",
    "Digital raw image" : "Digitaalne töötlemata pilt",
    "Windows Icon" : "Windowsi ikoon",
    "Email message" : "E-kiri",
    "VCS/ICS calendar" : "VCS/ICS-i kalender",
    "CSS stylesheet" : "CSS-i laaditabel",
    "CSV document" : "CSV-dokument",
    "HTML document" : "HTML-dokument",
    "Markdown document" : "Markdowni dokument",
    "Org-mode file" : "Org-mode'i fail",
    "Plain text document" : "Vormindamata tekstidokument",
    "Rich Text document" : "Vormindatud tekstidokument",
    "Electronic business card" : "Elektrooniline visiitkaart",
    "C++ source code" : "C++ lähtekood",
    "LDIF address book" : "LDIF-i aaddressiraamat",
    "NFO document" : "NFO-dokument",
    "PHP source" : "PHP lähtekood",
    "Python script" : "Pythoni skript",
    "ReStructuredText document" : "ReStructuredTexti dokument",
    "3GPP multimedia file" : "3GPP multimeediafail",
    "MPEG video" : "MPEG video",
    "DV video" : "DV video",
    "MPEG-2 transport stream" : "MPEG-2 transport stream",
    "MPEG-4 video" : "MPEG-4 video",
    "Ogg video" : "Ogg video",
    "QuickTime video" : "QuickTime video",
    "WebM video" : "WebM video",
    "Flash video" : "Flash video",
    "Matroska video" : "Matroska video",
    "Windows Media video" : "Windows Media video",
    "AVI video" : "AVI video",
    "Error occurred while checking server setup" : "Serveri seadete kontrolimisel tekkis viga",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Lisateavet leiad {linkstart}dokumentatsioonist ↗{linkend}.",
    "unknown text" : "tundmatu tekst",
    "Hello world!" : "Tere maailm!",
    "sunny" : "päikeseline",
    "Hello {name}, the weather is {weather}" : "Tere {name}, ilm on {weather}",
    "Hello {name}" : "Tere, {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Need on sinu otsingutulemused: <script>alert(1)</script></strong>",
    "new" : "uus",
    "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uuendamine on pooleli, sellelt lehelt lahkumine võib mõnes keskkonnas protsessi katkestada.",
    "Update to {version}" : "Uuenda versioonile {version}",
    "An error occurred." : "Tekkis viga.",
    "Please reload the page." : "Palun laadi leht uuesti.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uuendamine ebaõnnestus. Täiendavat infot <a href=\"{url}\">vaata meie foorumipostitusest</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uuendamine ebaõnnestus. Palun teavita probleemist <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloudi kogukonda</a>.",
    "Continue to {productName}" : "Jätka siit: {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uuendamine õnnestus. Sind suunatakse tagasi {productName} juurde %n sekundi pärast.","Uuendamine õnnestus. Sind suunatakse tagasi {productName} juurde %n sekundi pärast."],
    "Applications menu" : "Rakenduste menüü",
    "Apps" : "Rakendused",
    "More apps" : "Veel rakendusi",
    "_{count} notification_::_{count} notifications_" : ["{count} teavitus","{count} teavitust"],
    "No" : "Ei",
    "Yes" : "Jah",
    "The remote URL must include the user." : "Kaugserveri võrguaadressis peab leiduma kasutajanimi",
    "Invalid remote URL." : "Vigane kaugserveri võrguaadress",
    "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ei õnnestunud",
    "Federated user" : "Kasutaja liitpilves",
    "user@your-nextcloud.org" : "kasutaja@sinu-nextcloud.ee",
    "Create share" : "Lisa jagamine",
    "Direct link copied to clipboard" : "Otselink on lõikelauale kopeeritud",
    "Please copy the link manually:" : "Palun kopeeri link käsitsi:",
    "Custom date range" : "Sinu valitud kuupäevavahemik",
    "Pick start date" : "Vali algkuupäev",
    "Pick end date" : "Vali lõppkuupäev",
    "Search in date range" : "Otsi kuupäevavahemikust",
    "Search in current app" : "Otsi sellest rakendusest",
    "Clear search" : "Tühjenda otsing",
    "Search everywhere" : "Otsi kõikjalt",
    "Searching …" : "Otsin...",
    "Start typing to search" : "Otsimiseks alusta kirjutamist",
    "No matching results" : "Otsinguvastuseid ei leidu",
    "Today" : "Täna",
    "Last 7 days" : "Viimase 7 päeva jooksul",
    "Last 30 days" : "Viimase 30 päeva jooksul",
    "This year" : "Sel aastal",
    "Last year" : "Eelmisel aastal",
    "Unified search" : "Ühendatud otsing",
    "Search apps, files, tags, messages" : "Otsi rakendusi, faile, silte, sõnumeid",
    "Places" : "Kohad",
    "Date" : "Kuupäev",
    "Search people" : "Otsi inimesi",
    "People" : "Inimesed",
    "Filter in current view" : "Filtreeri selles vaates",
    "Results" : "Tulemused",
    "Load more results" : "Laadi veel tulemusi",
    "Search in" : "Otsi siin:",
    "Log in" : "Logi sisse",
    "Logging in …" : "Sisselogimisel...",
    "Log in to {productName}" : "Logi sisse: {productName}",
    "Wrong login or password." : "Vale kasutajanimi või salasõna.",
    "This account is disabled" : "See konto pole kasutusel",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Me tuvastasime sinu IP-aadressilt palju ebaõnnestunud sisselogimiskatseid. Seetõttu on su järgmine sisselogimine ootel kuni 30 sekundit.",
    "Account name or email" : "Konto nimi või e-posti aadress",
    "Account name" : "Kasutajakonto nimi",
    "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
    "Please contact your administrator." : "Palun võta ühendust oma administraatoriga.",
    "Session error" : "Sessiooniviga",
    "It appears your session token has expired, please refresh the page and try again." : "Tundub, et sinu sessiooni tunnusluba on aegunud, palun laadi leht ja proovi uuesti.",
    "An internal error occurred." : "Tekkis sisemine viga.",
    "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
    "Password" : "Salasõna",
    "Log in with a device" : "Logi sisse seadmega",
    "Login or email" : "Kasutajanimi või e-posti aadress",
    "Your account is not setup for passwordless login." : "Su konto ei ole seadistatud salasõnata sisenemise jaoks.",
    "Your connection is not secure" : "Ühendus ei ole turvaline",
    "Passwordless authentication is only available over a secure connection." : "Salasõnata autentimine eeldab turvalise võrguühenduse kasutamist.",
    "Browser not supported" : "Brauser pole toetatud",
    "Passwordless authentication is not supported in your browser." : "Sinu brauser ei toeta salasõnata sisselogimist.",
    "Reset password" : "Lähtesta salasõna",
    "Back to login" : "Tagasi sisse logima",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Kui selline kasutajakonto on olemas, siis salasõna lähtestamiseks vajalik kiri on saadetud tema e-posti aadressile. Kui sa pole kirja kätte saanud, siis palun kontrolli, et kasutajanimi või e-posti aadress on õiged, e-kiri pole sattunud rämpsposti kausta ning vajalusel küsi abi oma süsteemihaldurilt.",
    "Couldn't send reset email. Please contact your administrator." : "Ei suutnud saata lähtestamiseks vajalikku e-kirja. Palun võta ühendust serveri haldajaga või peakasutajaga.",
    "Password cannot be changed. Please contact your administrator." : "Salasõna ei saa muuta. Palun võta ühendust peakasutaja või süsteemihalduriga.",
    "New password" : "Uus salasõna",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Su failid on krüptitud. Pärast salasõna lähtestamist ei ole mingit võimalust su andmeid tagasi saada. Kui sa pole kindel, mida teha, võta palun ühendust oma süsteemi peakasutajaga. Kas soovid kindlasti jätkata?",
    "I know what I'm doing" : "Ma tean, mida teen",
    "Resetting password" : "Salasõna on lähtestamisel",
    "Schedule work & meetings, synced with all your devices." : "Planeeri tööd ja kohtumisi, süngitud kõigi su seadmetega.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Hoia oma kolleegid ja sõbrad ühes kohas ilma nende privaatset infot lekitamata.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Lihtne e-posti rakendus, mis on integreeritud Failide, Kontaktide ja Kalendriga.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Vestlused, videokõned, ekraanijagamine, veebipõhised kohtumised ja veebikonverentsid – sinu brauseris ja mobiilirakendustes.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kaastöö dokumentide, tabelite ja presentatsioonidega, kasutades Collabora Online'i.",
    "Distraction free note taking app." : "Müravaba märkmete rakendus.",
    "Recommended apps" : "Soovitatud rakendused",
    "Loading apps …" : "Rakenduste laadimine …",
    "Could not fetch list of apps from the App Store." : "Rakenduste loendi laadimine App Store'st ebaõnnestus.",
    "App download or installation failed" : "Rakenduse allalaadimine või paigaldamine ebaõnnestus",
    "Cannot install this app because it is not compatible" : "Seda rakendust ei saa paigaldada, kuna see pole ühilduv",
    "Cannot install this app" : "Seda rakendust ei saa paigaldada",
    "Skip" : "Jäta vahele",
    "Installing apps …" : "Rakenduste paigaldamine …",
    "Install recommended apps" : "Paigalda soovitatud rakendused",
    "Avatar of {displayName}" : "Kasutaja „{displayName}“ tunnuspilt",
    "Settings menu" : "Seadistuste menüü",
    "Loading your contacts …" : "Sinu kontaktide laadimine ...",
    "Looking for {term} …" : "Otsin {term} …",
    "Search contacts" : "Otsi kontakte",
    "Reset search" : "Lähtesta otsing",
    "Search contacts …" : "Otsi kontakte …",
    "Could not load your contacts" : "Sinu kontaktide laadimine ebaõnnestus",
    "No contacts found" : "Kontakte ei leitud",
    "Show all contacts" : "Näita kõiki kontakte",
    "Install the Contacts app" : "Paigalda Kontaktide rakendus",
    "Search" : "Otsi",
    "No results for {query}" : "„{query}“ päringul pole tulemusi",
    "Press Enter to start searching" : "Otsimise alustamiseks vajuta Enter",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Otsimiseks sisesta vähemalt {minSearchLength} sümbol","Otsimiseks sisesta vähemalt {minSearchLength} sümbolit"],
    "An error occurred while searching for {type}" : "„{type}“ otsimisel tekkis viga",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Otsing algab kohe, kui sa midagi trükid, ja tulemustele saab ligi nooleklahvidega",
    "Search for {name} only" : "Otsi vaid otsisõna „{name}“",
    "Loading more results …" : "Laadin veel tulemusi…",
    "Forgot password?" : "Unustasid salasõna?",
    "Back to login form" : "Tagasi sisselogimise lehele",
    "Back" : "Tagasi",
    "Login form is disabled." : "Sisselogimise leht on keelatud.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudi sisselogimisvorm on kasutusel eemaldatud. Kui mõni muu sisselogimisviis on saadaval, siis kasuta seda või küsi lisateavet oma süsteemihaldajalt.",
    "More actions" : "Täiendavad tegevused",
    "User menu" : "Kasutajamenüü",
    "You will be identified as {user} by the account owner." : "Kasutajakonto omanik tuvastab sind hetkel, kui {user}",
    "You are currently not identified." : "Sa pole hetkel tuvastatud",
    "Set public name" : "Lisa avalik nimi",
    "Change public name" : "Muuda avalikku nime",
    "Password is too weak" : "Salasõna on liiga nõrk",
    "Password is weak" : "Salasõna on nõrk",
    "Password is average" : "Salasõna on keskpärane",
    "Password is strong" : "Salasõna on tugev",
    "Password is very strong" : "Salasõna on väga tugev",
    "Password is extremely strong" : "Salasõna on ülitugev",
    "Unknown password strength" : "Salasõna tugevus pole teada",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Kuna <code>.htaccess</code> fail ei toimi, siis sinu andmekaust ja failid on ilmselt ligipääsetavad internetist.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Serveri õigeks seadistamiseks {linkStart}leiad teavet dokumentatsioonist{linkEnd}",
    "Autoconfig file detected" : "Tuvastasin autoconfig faili",
    "The setup form below is pre-filled with the values from the config file." : "Järgnev paigaldusvorm on eeltäidetud sellest failist leitud andmetega.",
    "Security warning" : "Turvahoiatus",
    "Create administration account" : "Loo peakasutaja konto",
    "Administration account name" : "Peakasutaja konto nimi",
    "Administration account password" : "Peakasutaja konto salasõna",
    "Storage & database" : "Andmehoidla ja andmebaas",
    "Data folder" : "Andmekaust",
    "Database configuration" : "Andmebaasi seadistused",
    "Only {firstAndOnlyDatabase} is available." : "Ainult {firstAndOnlyDatabase} on saadaval.",
    "Install and activate additional PHP modules to choose other database types." : "Paigalda ja aktiveeri täiendavaid PHP mooduleid, et teisi andmebaasi tüüpe valida.",
    "For more details check out the documentation." : "Lisainfot vaata dokumentatsioonist.",
    "Performance warning" : "Jõudluse hoiatus",
    "You chose SQLite as database." : "Sa valisid SQLite andmebaasi.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sobib kasutamiseks ainult arenduseks ja väikesemahulistes serverites. Toodangu jaoks soovitame teist andmebaasilahendust.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Kui kasutad Nextcloudi kliente, mis sünkroniseerivad faile, siis SQLite ei ole sobilik andmebaas.",
    "Database user" : "Andmebaasi kasutaja",
    "Database password" : "Andmebaasi salasõna",
    "Database name" : "Andmebaasi nimi",
    "Database tablespace" : "Andmebaasi tabeliruum",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Palun sisesta hostinimega koos pordi number (nt. localhost:5432).",
    "Database host" : "Andmebaasi host",
    "localhost" : "localhost",
    "Installing …" : "Paigaldan…",
    "Install" : "Paigalda",
    "Need help?" : "Vajad abi?",
    "See the documentation" : "Vaata dokumentatsiooni",
    "{name} version {version} and above" : "{name} versioon {version} ja uuemad",
    "This browser is not supported" : "See brauser pole toetatu",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Sinu brauser ei ole toetatud. Palun uuenda see uuema versiooni peale või vaheta toetatud brauseri vastu.",
    "Continue with this unsupported browser" : "Jätka selle mittetoetatud brauseriga",
    "Supported versions" : "Toetatud versioonid",
    "Search {types} …" : "Otsi „{types}“…",
    "Choose {file}" : "Vali „{file}“",
    "Choose" : "Vali",
    "Copy to {target}" : "Kopeeri kausta {target}",
    "Copy" : "Kopeeri",
    "Move to {target}" : "Teisalda kausta {target}",
    "Move" : "Teisalda",
    "OK" : "Sobib",
    "read-only" : "kirjutuskaitstud",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failikonflikt","{count} failikonflikti"],
    "One file conflict" : "Üks failikonflikt",
    "New Files" : "Uued failid",
    "Already existing files" : "Juba olemasolevad failid",
    "Which files do you want to keep?" : "Milliseid faile sa soovid alles hoida?",
    "If you select both versions, the copied file will have a number added to its name." : "Kui valid mõlemad versioonid, siis lisatakse kopeeritud faili nimele number.",
    "Cancel" : "Loobu",
    "Continue" : "Jätka",
    "(all selected)" : "(kõik valitud)",
    "({count} selected)" : "({count} valitud)",
    "Error loading file exists template" : "Viga faili olemasolu malli laadimisel",
    "Saving …" : "Salvestamine …",
    "seconds ago" : "sekundit tagasi",
    "Connection to server lost" : "Ühendus serveriga katkes",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tõrge lehe laadimisel, värskendamine %n sekundi pärast","Tõrge lehe laadimisel, värskendamine %n sekundi pärast"],
    "Add to a project" : "Lisa projektile",
    "Show details" : "Näita üksikasju",
    "Hide details" : "Peida üksikasjad",
    "Rename project" : "Muuda projekti nime",
    "Failed to rename the project" : "Projekti nime muutmine ei õnnestunud",
    "Failed to create a project" : "Projekti loomine ebaõnnestus",
    "Failed to add the item to the project" : "Objekti lisamine projekti ei õnnestunud",
    "Connect items to a project to make them easier to find" : "Et objekte oleks lihtsam leida, seo nad projektiga",
    "Type to search for existing projects" : "Olemasolevate projektide otsimiseks kirjuta midagi",
    "New in" : "Mida on uut",
    "View changelog" : "Vaata muudatuste logi",
    "No action available" : "Ühtegi tegevust pole saadaval",
    "Error fetching contact actions" : "Viga kontakti toimingute laadimisel",
    "Close \"{dialogTitle}\" dialog" : "Sulge „{dialogTitle}“ vaade",
    "Email length is at max (255)" : "E-kirja pikkus on jõudnud lubatud piirini (255)",
    "Non-existing tag #{tag}" : "Olematu silt #{tag}",
    "Restricted" : "Piiratud",
    "Invisible" : "Nähtamatu",
    "Delete" : "Kustuta",
    "Rename" : "Muuda nime",
    "Collaborative tags" : "Koostöö sildid",
    "No tags found" : "Silte ei leitud",
    "Clipboard not available, please copy manually" : "Lõikelaud pole saadaval. Palun kopeeri käsitsi",
    "Personal" : "Isiklik",
    "Accounts" : "Kasutajakontod",
    "Admin" : "Peakasutaja",
    "Help" : "Abiinfo",
    "Access forbidden" : "Ligipääs on keelatud",
    "You are not allowed to access this page." : "Sul pole õigust seda lehte vaadata.",
    "Back to %s" : "Tagasi siia: %s",
    "Page not found" : "Lehekülge ei leitud",
    "The page could not be found on the server or you may not be allowed to view it." : "Seda lehekülge selles serveris ei leidu või sul puudub õigus seda vaadata.",
    "Too many requests" : "Liiga palju päringuid",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Sinu võrgust tuli liiga palju päringuid. Proovi hiljem uuesti, või võta ühendust administraatoriga, kui tegu on veaga.",
    "Error" : "Viga",
    "Internal Server Error" : "Serveri sisemine viga",
    "The server was unable to complete your request." : "Server ei suutnud sinu päringut lõpetada.",
    "If this happens again, please send the technical details below to the server administrator." : "Kui see veel kord juhtub, saada tehnilised detailid allpool serveri administraatorile.",
    "More details can be found in the server log." : "Lisainfot võib leida serveri logist.",
    "For more details see the documentation ↗." : "Lisateavet leiad dokumentatsioonist ↗.",
    "Technical details" : "Tehnilised andmed",
    "Remote Address: %s" : "Kaugaadress: %s",
    "Request ID: %s" : "Päringu ID: %s",
    "Type: %s" : "Tüüp: %s",
    "Code: %s" : "Kood: %s",
    "Message: %s" : "Sõnum: %s",
    "File: %s" : "Fail: %s",
    "Line: %s" : "Rida: %s",
    "Trace" : "Jälg",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Tundub, et sa proovid Nextcloudi uuesti paigaldada. Aga CAN_INSTALL fail on seadistuste kaustast puudu. Jätkamiseks palun loo CAN_INSTALL fail seadistuste kausta.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ei õnnestunud eemaldada CAN_INSTALL faili seadistuste kaustast. Palun tee seda käsitsi.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "See rakendus vajab toimimiseks JavaScripti. Palun {linkstart}luba JavaScript{linkend} ning laadi see leht uuesti.",
    "Skip to main content" : "Mine põhisisu juurde",
    "Skip to navigation of app" : "Mine rakenduse asukohtade juurde",
    "Go to %s" : "Mine %s",
    "Get your own free account" : "Tee endale tasuta kasutajakonto",
    "Connect to your account" : "Ühenda oma kasutajakontoga",
    "Please log in before granting %1$s access to your %2$s account." : "Enne rakendusele %1$s oma %2$s kontole ligipääsu andmist logi sisse.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Kui sa just hetkel ei ole seadistamas uut seadet või rakendus, siis võib keegi sind proovida petta eesmärgiks ligipääsu saamine sinu andmetele. Sel juhul palun ära jätka ja võta ühendust oma süsteemihaldajaga.",
    "App password" : "Rakenduse salasõna",
    "Grant access" : "Anna ligipääs",
    "Alternative log in using app password" : "Alternatiivne sisselogimisvõimalus rakenduse salasõnaga",
    "Account access" : "Konto ligipääs",
    "Currently logged in as %1$s (%2$s)." : "Hetkel sisselogitus kasutajana %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Oled andmas rakendusele %1$s ligipääsu oma %2$s kontole.",
    "Account connected" : "Konto ühendatud",
    "Your client should now be connected!" : "Su klient peaks nüüd olema ühendatud!",
    "You can close this window." : "Võid selle akna sulgeda.",
    "Previous" : "Eelmine",
    "This share is password-protected" : "See jaoskaust on salasõnaga kaitstud",
    "The password is wrong or expired. Please try again or request a new one." : "Salasõna on vale või aegunud. Palun proovi uuesti või taotle uut salasõna.",
    "Please type in your email address to request a temporary password" : "Palun sisesta oma e-posti aadress ajutise salasõna taotlemiseks",
    "Email address" : "E-posti aadress",
    "Password sent!" : "Salasõna on saadetud!",
    "You are not authorized to request a password for this share" : "Sul pole luba selle jaoskausta salasõna taotlemiseks",
    "Two-factor authentication" : "Kaheastmeline autentimine",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Sinu kontol on kasutusel täiendava turvalisuse meetmed. Vali kaheastmelise autentimise jaoks täiendav meetod:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ei õnnestunud laadida vähemalt ühte sinu valitud kaheastmelise autentimise meetodit. Palun võta ühendust oma süsteemihaldajaga.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaheastmeline autentimine on kohustuslik, aga sinu kasutajakonto jaoks seadistamata. Abiteavet saad oma süsteemihaldurilt.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Kaheastmeline autentimine on kohustuslik, aga sinu kasutajakonto jaoks seadistamata. Palun jätka kaheastmelise autentimise seadistamisega.",
    "Set up two-factor authentication" : "Võta kasutusele kaheastmeline autentimine",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Kaheastmeline autentimine on kohustuslik, aga sinu kasutajakonto jaoks seadistamata. Kasuta sisselogimiseks mõnda oma tagavarakoodidest või küsi abi oma süsteemihaldurilt.",
    "Use backup code" : "Kasuta varukoodi",
    "Cancel login" : "Katkesta sisselogimine",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Sinu kontol on kasutusel täiendava turvalisuse meetmed. Vali teenusepakkuja, mida soovid kasutada:",
    "Error while validating your second factor" : "Teise faktori valideerimise viga",
    "Access through untrusted domain" : "Ligipääs läbi ebausaldusväärse domeeni",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Palun võta ühendust oma administraatoriga. Kui oled administraator, muuda konfiguratsioonifailis config/config.php sätet \"trusted_domains\", nagu näidis config.sample.php failis.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Rohkem infot selle seadistamiseks leiab %1$s dokumentatsioonist %2$s.",
    "App update required" : "Rakenduse uuendus on nõutud",
    "%1$s will be updated to version %2$s" : "%1$s uuendatakse versioonile %2$s",
    "The following apps will be updated:" : "Järgmised rakendused uuendatakse:",
    "These incompatible apps will be disabled:" : "Need mitteühilduvad rakendused lülitatakse välja:",
    "The theme %s has been disabled." : "Teema %s on keelatud.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enne jätkamist veendu, et andmebaas ning seadete ja andmete kataloogid on varundatud.",
    "Start update" : "Käivita uuendus",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
    "Detailed logs" : "Üksikasjalikud logid",
    "Update needed" : "Uuendamine vajaliik",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Kuna sul on enam kui 50 kasutajaga server, siis palun kasuta uuendamiseks käsureal toimivat uuendajat.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Abi saamiseks vaata <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentatsiooni</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Olen teadlik, et veebiliidese kaudu uuendusega jätkamine hõlmab riski, et päring aegub ja põhjustab andmekadu, aga mul on varundus ja ma tean, kuidas tõrke korral oma instantsi taastada.",
    "Upgrade via web on my own risk" : "Uuenda veebi kaudu omal vastutusel",
    "Maintenance mode" : "Hooldusrežiim",
    "This %s instance is currently in maintenance mode, which may take a while." : "See %s instants on hetkel hooldusrežiimis, mis võib kesta mõnda aega.",
    "This page will refresh itself when the instance is available again." : "See leht värskendab ennast ise, kui instants jälle saadaval on.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Võta ühendust administraatoriga, kui see teade püsib või on tekkinud ootamatult.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Vestlused, videokõned, ekraanijagamine, online kohtumised ja veebikonverentsid – sinu brauseris ja mobiilirakendustes.",
    "You have not added any info yet" : "Sa pole veel mingit infot lisanud",
    "{user} has not added any info yet" : "{user} pole veel mitte mingit infot lisanud",
    "Error opening the user status modal, try hard refreshing the page" : "Kasutaja staatuse modaaldialoogi avamine ebaõnnestus, proovi lehte värskendada",
    "Edit Profile" : "Muuda profiili",
    "The headline and about sections will show up here" : "Alapealkirja ja teabe lõigud saavad olema nähtavad siin",
    "Very weak password" : "Väga nõrk salasõna",
    "Weak password" : "Nõrk salasõna",
    "So-so password" : "Enam-vähem sobiv salasõna",
    "Good password" : "Hea salasõna",
    "Strong password" : "Väga hea salasõna",
    "Profile not found" : "Profiili ei leitud",
    "The profile does not exist." : "Profiili ei eksisteeri",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmekataloog ja failid on tõenäoliselt internetist vabalt ligipääsetavad, kuna .htaccess fail ei toimi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Serveri õigeks seadistamiseks leiad infot <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentatsioonist</a>.",
    "<strong>Create an admin account</strong>" : "Loo <strong>peakasutaja konto</strong>",
    "New admin account name" : "Uue peakasutaja konto nimi",
    "New admin password" : "Uue peakasutaja salasõna",
    "Show password" : "Näita salasõna",
    "Toggle password visibility" : "Lülita salasõna nähtavus sisse/välja",
    "Configure the database" : "Seadista andmebaasi",
    "Only %s is available." : "Ainult %s on saadaval.",
    "Database account" : "Andmebaasi kasutajakonto"
},
"nplurals=2; plural=(n != 1);");
